There are several useful resources for iOS developers. I have not organized the links by rating. The links are grouped by material type - video, text, news, etc.

The description under each resource is collective feedback from the community. It's meant to help you get oriented more quickly.

If you know of any good resources, [contact me](https://t.me/ivanvorobei) and I'll add them here.

## Apple Resources

[Design](https://developer.apple.com/design/resources/): UI elements and ready-made templates from them. Available for Sketch, Photoshop, and XD. The latest version of San Francisco and New York fonts. "Available in AppStore" badges and more.

[Development](https://developer.apple.com/documentation/): Developer Documentation. Tutorials talk about technologies with code examples. Tutorials about Xcode Cloud and Concurrency are already available.

[Guide](https://developer.apple.com/design/): About interface design - architecture, gestures, UI elements, etc. There are interactive videos for clarity.

[UIKit item catalog](https://developer.apple.com/documentation/uikit/views_and_controls/uikit_catalog_creating_and_customizing_views_and_controls): Application with examples of customization by native items from `UIKit`.

[Release](https://developer.apple.com/download/release/): New versions of operating systems and applications. You can see a list of release notes and download Xcode from the site.

[WWDC video](https://developer.apple.com/videos/): Video tutorials from the WWDC session. Available English subtitles. Speakers speak slowly and with vivid graphics - you can watch even with poor English.

[Application promote](https://tools.applemediaservices.com/apple-app-store-promote): Available styles are `new application`, `update`, `subscription` and `offer`.  Configurable language and background color. Available sizes for stories, banners, and squares.

## Russian speaking videos

[Mobile development school from Yandex](https://www.youtube.com/playlist?list=PLQC2_0cDcSKBUXhSGqAbVAp3SFBKPnpFI): Great speakers and good content. The clips are 1-2 hours long. The sound is recorded from a webcam.

[Sparrow Code](https://www.youtube.com/channel/UCNUGzZfcOyX4YpP36VzeZ6A): Your humble servant's channel. I should do videos a little more often.

[iCode School](https://www.youtube.com/channel/UCx1xu0yc1mh-gjAq8YKRobg): Each video is dedicated to a specific class. For beginners, check out the playlist `Fundamentals of Programming. The author is pleasant to listen to, but the sound leaves a lot to be desired.

[Ivan Skorokhod](https://www.youtube.com/channel/UChfEfFKYILtO5yZSX2irynw): Translation of the Stanford course on iOS development. There are clips about Swift. Good presentation, bad sound.

[SwiftBook](https://www.youtube.com/channel/UCXlCPCsB09ftBA5bQfiSWoQ): Interviews with developers and practical problems. The author reads out the code he types - it bored me. Good sound.

[MadBrains](https://www.youtube.com/c/MadBrains): In the format of technical reports are solved practical problems. There are videos on how to get a failure and about RX. The clips are large, but it`s interesting to watch.

## Russian speaking tutorials

[Habr](https://habr.com/ru/hub/ios_dev/): A site with tutorials and real-world problems.  The authors answer in the comments. The link I gave was specifically for iOS development, but check out the other threads as well.

[Apptractor](https://apptractor.ru): In the [telegram channel](https://telegram.me/apptractor) comes a daily compilation of tutorials. On each Sunday, a digest of the week's content.

[SwiftBook](https://swiftbook.ru): Tutorials and translations. Swift documentation in Russian. There is a paid course for iOS developers.

## International tutorials

[Ray Wenderlich](https://www.raywenderlich.com): Great tutorials in a practical context. The author has books on git, database, and `SwiftUI'. There are video courses. Some content is paid.

[useyourloaf.com](https://useyourloaf.com): Short articles with practice. Often find the site in the output. Improved Stackoverflow.

[iosdevweekly.com](https://iosdevweekly.com): Compilations are categorized by tools, code, design, and marketing. Similar to `AppTractor`, yet international.

[hackingwithswift.com](https://www.hackingwithswift.com/): Short tutorials. I often see them in Google search results. There are paid courses.

[swiftsenpai.com](https://swiftsenpai.com): They take apart complex techniques. Many tutorials on new technologies.

[nshipster.com](https://nshipster.com): Deep-dive tutorials. There are about the development environment and dependencies.

[swiftontap.com](https://swiftontap.com): Documentation on `SwiftUI` with examples. A practical guide.

[theswiftdev.com](https://theswiftdev.com): Tutorials with non-classical practical tasks like how to run swift files like scripts and handle preprocessor info.

## International videos

[Stanford CS193p](https://www.youtube.com/playlist?list=PL3d_SFOiG7_8ofjyKzX6Nl1wZehbdiZC_): A popular course among junior developers. If you are fluent in English, start with this one. There are links to translations in the localized resources section.

[Kavsoft](https://www.youtube.com/c/Kavsoft): Tutorials and practical examples in SwiftUI. The author does not give voice-overs, the explanations appear as text on the screen.

## Chats

[Sparrow Code chat](https://sparrowcode.io/telegram/chat): Our chat room. We monitor toxic developers, help beginners and continuing developers.

[SwiftBook chat](https://telegram.me/swiftbook_chat): The chat room of a popular platform. There are more than 5k people in the chat room now.

## Library picks

[cocoacontrols.com](https://www.cocoacontrols.com): A compilation of UI libraries, with a preview.

[swiftpackageindex.com](https://swiftpackageindex.com): Searching for SPM libraries. The author chooses the libraries.

[iosdev.tools](https://iosdev.tools): A brief overview of libraries in news format.

[swift.libhunt.com](https://swift.libhunt.com): The libraries are divided into 74 categories. Ads interfere with navigation.

## Must have a library

[Alamofire](https://github.com/Alamofire/Alamofire): Basis for network requests.

[SwiftyJSON](https://github.com/SwiftyJSON/SwiftyJSON): Faster way to decode `JSON`.

[Nuke](https://github.com/kean/Nuke): Uses native tools for caching images.

[SPPermissions](https://github.com/ivanvorobei/SPPermissions): Handling permissions.

## Useful repositories

[Awesome-iOS](https://github.com/vsouza/awesome-ios): A compilation of libraries. The repositories are organized into 200 categories. There are compilations with courses.

[One more Awesome iOS](https://github.com/ivanvorobei/awesome-ios): My library compilation. There is a [website](https://awesome-ios.com). I have a plan to write an app.

[GitHub Trends](https://github.com/trending/swift?since=daily&spoken_language_code=): Popular Swift libraries on GitHub.

## Tools

[nsdateformatter.com](https://nsdateformatter.com): Examples of date formatting with `DateFormatter`.

[epochconverter.com](https://www.epochconverter.com): Converter `Timestamp`.

[Application promote](https://tools.applemediaservices.com/apple-app-store-promote): Available styles are `new application`, `update`, `subscription` and `offer`.  Configurable language and background color. Available sizes for stories, banners, and squares.

## QA

[Stackoverflow](https://stackoverflow.com): More often than not, a Google query will lead you here. You can ask your questions. It has a rating system.

[Russian Stackoverflow](https://ru.stackoverflow.com): The analog of the English-speaking portal. Not active in the Russian segment.

[Q&A](https://qna.habr.com): Q&A but Russian.

## That's all

If you know of any good resources, [contact me](https://t.me/ivanvorobei) to add them to the article.
